@@ -2,7 +2,7 @@
 
     A simple MTD for Intel Series 2+ Flash devices
 
-    iflash2+_mtd.c 1.74 2001/10/25 01:36:55
+    iflash2+_mtd.c 1.75 2002/06/29 06:27:37
 
     The contents of this file are subject to the Mozilla Public
     License Version 1.1 (the "License"); you may not use this file
@@ -36,9 +36,6 @@
     
 ======================================================================*/
 
-#include <pcmcia/config.h>
-#include <pcmcia/k_compat.h>
-
 #include <linux/kernel.h>
 #include <linux/module.h>
 #include <linux/init.h>
@@ -90,7 +87,7 @@ INT_MODULE_PARM(do_sleep, 1);			/* spin vs sleep? */
 INT_MODULE_PARM(pc_debug, PCMCIA_DEBUG);
 #define DEBUG(n, args...) do { if (pc_debug>(n)) printk(KERN_INFO args); } while (0)
 static char *version =
-"iflash2+_mtd.c 1.74 2001/10/25 01:36:55 (David Hinds)";
+"iflash2+_mtd.c 1.75 2002/06/29 06:27:37 (David Hinds)";
 #else
 #define DEBUG(n, args...) do { } while (0)
 #endif
