@@ -2,7 +2,7 @@
 
     A simple MTD for Intel Series 2 and Series 100 Flash devices
 
-    iflash2_mtd.c 1.64 2001/10/25 01:36:55
+    iflash2_mtd.c 1.65 2002/06/29 06:27:37
 
     The contents of this file are subject to the Mozilla Public
     License Version 1.1 (the "License"); you may not use this file
@@ -36,9 +36,6 @@
     
 ======================================================================*/
 
-#include <pcmcia/config.h>
-#include <pcmcia/k_compat.h>
-
 #include <linux/kernel.h>
 #include <linux/module.h>
 #include <linux/init.h>
@@ -88,7 +85,7 @@ INT_MODULE_PARM(max_tries, 4096);		/* status polling */
 INT_MODULE_PARM(pc_debug, PCMCIA_DEBUG);
 #define DEBUG(n, args...) do { if (pc_debug>(n)) printk(KERN_INFO args); } while (0)
 static char *version =
-"iflash2_mtd.c 1.64 2001/10/25 01:36:55 (David Hinds)";
+"iflash2_mtd.c 1.65 2002/06/29 06:27:37 (David Hinds)";
 #else
 #define DEBUG(n, args...) do { } while (0)
 #endif
