@@ -11,7 +11,7 @@
 
     Copyright (C) 1999 David A. Hinds -- dahinds@users.sourceforge.net
 
-    pcnet_cs.c 1.147 2002/03/02 21:37:36
+    pcnet_cs.c 1.152 2003/08/25 15:57:41
     
     The network driver code is based on Donald Becker's NE2000 code:
 
@@ -28,9 +28,6 @@
 
 ======================================================================*/
 
-#include <pcmcia/config.h>
-#include <pcmcia/k_compat.h>
-
 #include <linux/kernel.h>
 #include <linux/module.h>
 #include <linux/init.h>
@@ -43,6 +40,7 @@
 #include <asm/io.h>
 #include <asm/system.h>
 #include <asm/byteorder.h>
+#include <asm/uaccess.h>
 
 #include <linux/netdevice.h>
 #include <../drivers/net/8390.h>
@@ -67,7 +65,7 @@
 #define SOCKET_START_PG	0x01
 #define SOCKET_STOP_PG	0xff
 
-#define PCNET_RDC_TIMEOUT 0x02	/* Max wait in jiffies for Tx RDC */
+#define PCNET_RDC_TIMEOUT (2*HZ/100)	/* Max wait in jiffies for Tx RDC */
 
 static char *if_names[] = { "auto", "10baseT", "10base2"};
 
@@ -76,7 +74,7 @@ static int pc_debug = PCMCIA_DEBUG;
 MODULE_PARM(pc_debug, "i");
 #define DEBUG(n, args...) if (pc_debug>(n)) printk(KERN_DEBUG args)
 static char *version =
-"pcnet_cs.c 1.147 2002/03/02 21:37:36 (David Hinds)";
+"pcnet_cs.c 1.152 2003/08/25 15:57:41 (David Hinds)";
 #else
 #define DEBUG(n, args...)
 #endif
@@ -301,7 +299,8 @@ static dev_link_t *pcnet_attach(void)
     memset(info, 0, sizeof(*info));
     link = &info->link; dev = &info->dev;
     link->priv = info;
-    
+
+    init_timer(&link->release);
     link->release.function = &pcnet_release;
     link->release.data = (u_long)link;
     link->irq.Attributes = IRQ_TYPE_EXCLUSIVE;
@@ -766,7 +765,6 @@ static void pcnet_config(dev_link_t *link)
 
     copy_dev_name(info->node, dev);
     link->dev = &info->node;
-    link->state &= ~DEV_CONFIG_PENDING;
 
     if (info->flags & (IS_DL10019|IS_DL10022)) {
 	u_char id = inb(dev->base_addr + 0x1a);
@@ -788,12 +786,14 @@ static void pcnet_config(dev_link_t *link)
     printk(" hw_addr ");
     for (i = 0; i < 6; i++)
 	printk("%02X%s", dev->dev_addr[i], ((i<5) ? ":" : "\n"));
+    link->state &= ~DEV_CONFIG_PENDING;
     return;
 
 cs_failed:
     cs_error(link->handle, last_fn, last_ret);
 failed:
     pcnet_release((u_long)link);
+    link->state &= ~DEV_CONFIG_PENDING;
     return;
 } /* pcnet_config */
 
@@ -857,7 +857,7 @@ static int pcnet_event(event_t event, int priority,
 	}
 	break;
     case CS_EVENT_CARD_INSERTION:
-	link->state |= DEV_PRESENT;
+	link->state |= DEV_PRESENT | DEV_CONFIG_PENDING;
 	pcnet_config(link);
 	break;
     case CS_EVENT_PM_SUSPEND:
@@ -1257,8 +1257,8 @@ static void dma_get_8390_hdr(struct net_device *dev,
     outb_p(ring_page, nic_base + EN0_RSARHI);
     outb_p(E8390_RREAD+E8390_START, nic_base + PCNET_CMD);
 
-    insw_ns(nic_base + PCNET_DATAPORT, hdr,
-	    sizeof(struct e8390_pkt_hdr)>>1);
+    insw(nic_base + PCNET_DATAPORT, hdr,
+	 sizeof(struct e8390_pkt_hdr)>>1);
     /* Fix for big endian systems */
     hdr->count = le16_to_cpu(hdr->count);
 
@@ -1293,7 +1293,7 @@ static void dma_block_input(struct net_device *dev, int count,
     outb_p(ring_offset >> 8, nic_base + EN0_RSARHI);
     outb_p(E8390_RREAD+E8390_START, nic_base + PCNET_CMD);
 
-    insw_ns(nic_base + PCNET_DATAPORT,buf,count>>1);
+    insw(nic_base + PCNET_DATAPORT,buf,count>>1);
     if (count & 0x01)
 	buf[count-1] = inb(nic_base + PCNET_DATAPORT), xfer_count++;
 
@@ -1366,7 +1366,7 @@ static void dma_block_output(struct net_device *dev, int count,
     outb_p(start_page, nic_base + EN0_RSARHI);
 
     outb_p(E8390_RWRITE+E8390_START, nic_base + PCNET_CMD);
-    outsw_ns(nic_base + PCNET_DATAPORT, buf, count>>1);
+    outsw(nic_base + PCNET_DATAPORT, buf, count>>1);
 
     dma_start = jiffies;
 
